==> syslog-ng_3.13.2.orig.tar.gz: syslog-ng-syslog-ng-3.13.2/modules/java-modules/elastic-v2/src/main/java/org/syslog_ng/elasticsearch_v2/messageprocessor/http/HttpSingleMessageProcessor.java <==
/*
 * Copyright (c) 2016 Balabit
 * Copyright (c) 2016 Laszlo Budai <laszlo.budai@balabit.com>
 * Copyright (c) 2016 Viktor Tusa <tusavik@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * As an additional exemption you are allowed to compile & link against the
 * OpenSSL libraries as published by the OpenSSL project. See the file
 * COPYING for details.
 *
 */

package org.syslog_ng.elasticsearch_v2.messageprocessor.http;

import io.searchbox.core.Index;
import io.searchbox.client.JestResult;
import org.syslog_ng.elasticsearch_v2.ElasticSearchOptions;
import org.syslog_ng.elasticsearch_v2.client.http.ESHttpClient;

import java.io.IOException;

public class HttpSingleMessageProcessor extends  HttpMessageProcessor {

	public HttpSingleMessageProcessor(ElasticSearchOptions options, ESHttpClient client) {
		super(options, client);
	}

	@Override
	public boolean send(Index req) {
		boolean result = true;
	  JestResult jestResult = null;
		try {
			jestResult = client.getClient().execute(req);
		}
		catch (IOException e)
		{
			logger.error(e.getMessage());
			result = false;
		}
		if (! jestResult.isSucceeded()) {
			logger.error(jestResult.getErrorMessage());
			result = false;
		}
		return result;
	}

}

==> syslog-ng_4.8.1.orig.tar.gz: syslog-ng-syslog-ng-4.8.1/modules/java-modules/elastic-v2/src/main/java/org/syslog_ng/elasticsearch_v2/messageprocessor/http/HttpSingleMessageProcessor.java <==
/*
 * Copyright (c) 2016 Balabit
 * Copyright (c) 2016 Laszlo Budai <laszlo.budai@balabit.com>
 * Copyright (c) 2016 Viktor Tusa <tusavik@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * As an additional exemption you are allowed to compile & link against the
 * OpenSSL libraries as published by the OpenSSL project. See the file
 * COPYING for details.
 *
 */

package org.syslog_ng.elasticsearch_v2.messageprocessor.http;

import io.searchbox.core.Index;
import io.searchbox.client.JestResult;
import org.syslog_ng.elasticsearch_v2.ElasticSearchOptions;
import org.syslog_ng.elasticsearch_v2.client.http.ESHttpClient;

import java.io.IOException;

public class HttpSingleMessageProcessor extends  HttpMessageProcessor {

	public HttpSingleMessageProcessor(ElasticSearchOptions options, ESHttpClient client) {
		super(options, client);
	}

	@Override
	public boolean send(Index req) {
	  JestResult jestResult = null;
		try {
			jestResult = client.getClient().execute(req);
		}
		catch (IOException e)
		{
			logger.error(e.getMessage());
			return false;
		}
		if (! jestResult.isSucceeded()) {
			logger.error(jestResult.getErrorMessage());
			return false;
		}
		return true;
	}

}
